@@ -19,8 +19,9 @@ union nftnl_data_reg {
 		uint32_t	len;
 	};
 	struct {
-		int		verdict;
+		uint32_t	verdict;
 		const char	*chain;
+		uint32_t	chain_id;
 	};
 };
 
